@@ -8,6 +8,6 @@
 check_week <- function(the_interval) {
   num_week  <- is.numeric(the_interval) && the_interval == 7
   int_week  <- is.integer(the_interval) && the_interval == 7L
-  char_week <- is.character(the_interval) && grepl(the_interval, "week")
+  char_week <- is.character(the_interval) && grepl("week", the_interval, ignore.case = TRUE)
   num_week || int_week || char_week
 }
